@@ -35,8 +35,7 @@ $HR001="Last time edited: ";
 $HR002="by";
 
 // Info Botton
-$IB000="Edit (GUI)";
-$IB001="Edit (text)";
+$IB001="Edit";
 $IB002="Delete";
 
 // Info Edition Messages (IEM)
