@@ -33,9 +33,8 @@ Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
 $TEXT001="Panel de Control";
 $TEXT002="Usuarios";
 $TEXT003="Configuraci&oacute;n";
-$TEXT004="Apariencia";
-$TEXT005="Estad&iacute;sticas";
-$TEXT006="Creditos";
+$TEXT004="Estilo";
+$TEXT005="Creditos";
 $TEXT007="No te has validado como un usuario autorizado !<br>".
          "El Panel de Control es solo para usuarios registrados<br>con privilegios de administrador.<br>".
          "Probablemente usted no deber&iacute;a estar aqu&iacute;.";
