@@ -43,8 +43,8 @@ $GBL005="Entrar"; //Text value for submit button
 $GBL006="Bienvenido";
 $GBL007="Autenticaci&oacute;n Correcta.<br>".
         "Acabas de conectar como un usuairo registrado<br><br>".
-        "Si continuas, podr&aacute; acceder a las funciones de usuario.<br>".
-        "Sea cuidadoso !";
+        "Si continuas, podr&aacute;s acceder a las funciones de usuario.<br>".
+        "Se cuidadoso !";
 $GBL008="Continuar";
 
 // GBL when user is already logged
