@@ -35,8 +35,7 @@ $HR001="Editado por &uacute;ltima vez: ";
 $HR002="por";
 
 // Info Botton
-$IB000="Editar (GUI)";
-$IB001="Editar (texto)";
+$IB001="Editar";
 $IB002="Borrar";
 
 // Info Edition Messages (IEM)
