@@ -72,21 +72,23 @@ if (!empty($login) && !empty($password))
 
 if (($id_session[num]!=$num && $auth=="no") || (!isset($id_session[num]) && $auth=="no"))
    {
-   echo "<td width=\"100%\" bgcolor=$fondo class=\"text1\" align=\"center\">\n";
-   echo "$TITLE $GBL001<br><br>\n";
-   echo "<form method=\"post\" action=\"index.php?top_tab=$top_tab&section_type=$section_type&num=$num\">\n";
-   echo "$GBL002<br><input type=\"text\" name=\"nick\" size=\"8\"><br><br>\n";
-   echo "$GBL003<br><input type=\"password\" name=\"password\" size=\"8\"><br><br>\n";
-   echo "<input type=\"submit\" value=\"$GBL005\">\n";
-   echo "</form>\n";
-   echo "<br><div class=\"link1\"><a href=\"index.php?top_tab=5&section_type=1&user_section=3\">$GBL004</a></div>";
-   echo "</td>\n";
+   echo "<td width=\"100%\" bgcolor=$fondo class=\"text1\" align=\"center\">".
+        "$TITLE $GBL001<br><br>";
+   if ($AUTH_LOGIN=="no") echo "<span class=\"alert1b\" align=\"center\">$GBL017</span><br>";
+   if ($AUTH_PASSWD=="no") echo "<span class=\"alert1b\" align=\"center\">$GBL018</span><br>";
+   echo "<form method=\"post\" action=\"index.php?top_tab=$top_tab&section_type=$section_type&num=$num\">".
+        "$GBL002<br><input type=\"text\" name=\"nick\" size=\"8\"><br><br>".
+        "$GBL003<br><input type=\"password\" name=\"password\" size=\"8\"><br><br>".
+        "<input type=\"submit\" value=\"$GBL005\">".
+        "</form>".
+        "<br><div class=\"link1\"><a href=\"index.php?top_tab=5&section_type=1&user_section=3\">$GBL004</a></div>".
+        "</td>";
    } else if ($id_session[num]==$num && isset($id_session[num]))
              {
-             echo "<td width=\"100%\" bgcolor=$fondo align=\"center\">";
-             echo "<span class=\"text1\">$GBL009 <b>$id_session[user]</b></span>";
-             echo "<span class=\"text2\"><br><br>$GBL010<br><br></span>";
-             echo "<span class=\"link1\"><a href=\"index.php?top_tab=5&section_type=1&user_section=0".
+             echo "<td width=\"100%\" bgcolor=$fondo align=\"center\">".
+                  "<span class=\"text1\">$GBL009 <b>$id_session[user]</b></span>".
+                  "<span class=\"text2\"><br><br>$GBL010<br><br></span>".
+                  "<span class=\"link1\"><a href=\"index.php?top_tab=5&section_type=1&user_section=0".
                   "&num=$num\">$GBL011</a></br></span>";
              // We need to know where the pending items are.
              include ("includes/db_connect.php");
@@ -113,7 +115,7 @@ if (($id_session[num]!=$num && $auth=="no") || (!isset($id_session[num]) && $aut
                    }
                 } else echo "<span class=\"text1\">$GBL014 ($pending_items)</a></br></span>";
              echo "<span class=\"link1\"><a href=\"index.php?top_tab=5&section_type=4".
-                  "&num=$num\">$GBL015</a></br></span>";
-             echo "<span class=\"link1\"><a href=\"index.php?top_tab=1&section_type=$section_type&logout=yes\"><br>$GBL016</a></span></td>";
+                  "&num=$num\">$GBL015</a></br></span>".
+                  "<span class=\"link1\"><a href=\"index.php?top_tab=1&section_type=$section_type&logout=yes\"><br>$GBL016</a></span></td>";
              }
 ?>
