@@ -67,6 +67,9 @@ if($login==$datos_form["nick"] && $password==$datos_form["password"] && !empty($
   } else $num=$numero; // If the user still logged, then the $num value don't change
 
 
+if($login!=$datos_form["nick"] ) $AUTH_LOGIN="no";
+if ($password!=$datos_form["password"]) $AUTH_PASSWD="no";
+
 include ("includes/draw_main_table.php");
 include ("includes/draw_functions.php");
 ?>
@@ -90,28 +93,28 @@ include ("includes/draw_functions.php");
 if ($SIZE_BOX1>0)
    {
    echo "<td width=$WIDTH_BOX1>";
-   draw_table ($COLOR_BOX1,$SIZE_BOX1,"".$LOGO_BOX1."","",$SKIN_BOX1,"","");
+   draw_table ($COLOR_BOX1,$SIZE_BOX1,"".$LOGO_BOX1."","",$SKIN_BOX1,"","","","");
    echo "</td>";
    }
 
 if ($SIZE_BOX2>0)
    {
    echo "<td width=$WIDTH_BOX2>";
-   draw_table ($COLOR_BOX2,$SIZE_BOX2,"".$LOGO_BOX2."","",$SKIN_BOX2,"","");
+   draw_table ($COLOR_BOX2,$SIZE_BOX2,"".$LOGO_BOX2."","",$SKIN_BOX2,"","","","");
    echo "</td>";
    }
 
 if ($SIZE_BOX3>0)
    {
    echo "<td width=$WIDTH_BOX3>";
-   draw_table ($COLOR_BOX3,$SIZE_BOX3,"".$LOGO_BOX3."","",$SKIN_BOX3,"","");
+   draw_table ($COLOR_BOX3,$SIZE_BOX3,"".$LOGO_BOX3."","",$SKIN_BOX3,"","","","");
    echo "</td>";
    }
 
 if ($SIZE_BOX4>0)
    {
    echo "<td width=$WIDTH_BOX4>";
-   draw_table ($COLOR_BOX4,$SIZE_BOX4,"".$LOGO_BOX4."","",$SKIN_BOX4,"","");
+   draw_table ($COLOR_BOX4,$SIZE_BOX4,"".$LOGO_BOX4."","",$SKIN_BOX4,"","","","");
    echo "</td>";
    }
 ?>
@@ -125,7 +128,7 @@ if ($SIZE_BOX4>0)
 
 <tr>
 <!-- LEFT BOX -->
-<td valign="top"><? draw_table ($COLOR_LEFT_BOX,$SIZE_LEFT_BOX,"EXTERNO","includes/left_table.php",$SKIN_LEFT_BOX,$num,"") ?></td>
+<td valign="top"><? draw_table ($COLOR_LEFT_BOX,$SIZE_LEFT_BOX,"EXTERNO","includes/left_table.php",$SKIN_LEFT_BOX,$num,"","","") ?></td>
 
 <td colspan="2" valign="top">
 
@@ -245,16 +248,16 @@ if ($SIZE_BOX4>0)
 
 <td valign="top">
 <!-- RIGHT BOX -->
-<? draw_table ($COLOR_BOX5,$SIZE_BOX5,"".$LOGO_BOX5."","",$SKIN_BOX5,"","") ?><br>
+<? draw_table ($COLOR_BOX5,$SIZE_BOX5,"".$LOGO_BOX5."","",$SKIN_BOX5,"","","","") ?><br>
 
 <!-- LOGIN BOX -->
-<? draw_table ($COLOR_LOGIN_BOX,$SIZE_LOGIN_BOX,"EXTERNO","includes/login.php",$SKIN_LOGIN_BOX,$num,$id_session) ?> 
+<? draw_table ($COLOR_LOGIN_BOX,$SIZE_LOGIN_BOX,"EXTERNO","includes/login.php",$SKIN_LOGIN_BOX,$num,$id_session,$AUTH_LOGIN,$AUTH_PASSWD) ?> 
 
 </td></tr>
 
 <tr> <!-- FOOTER BOX -->
 <td colspan=4>
-<? draw_table ($COLOR_FOOTER_BOX,$SIZE_FOOTER_BOX,"<div class=\"text1\" align=\"center\">".$LOGO_FOOTER_BOX."</div>","","$SKIN_FOOTER_BOX","","") ?></td>
+<? draw_table ($COLOR_FOOTER_BOX,$SIZE_FOOTER_BOX,"<div class=\"text1\" align=\"center\">".$LOGO_FOOTER_BOX."</div>","","$SKIN_FOOTER_BOX","","","","") ?></td>
 </tr>
 
 </table>
