@@ -228,15 +228,17 @@ if ($num_infos > 10)
 
 }
 
-// If the user was loged and selects the edit option (task==edit), then he can modify the whole section.
+// task=edit
+
 $current_user_query=mysql_query("SELECT level FROM users WHERE id_user='".$id_session[id_user]."'", $db);
 $current_user=mysql_fetch_array ($current_user_query);
-
-if ($task=="edit" && $current_user["level"] >= "50")
+if (isset($_GET['id_info'])) {$id_info=$_GET['id_info'];} else if (isset($_POST['id_info'])) {$id_info=$_POST['id_info'];}
+$info_query=mysql_query("SELECT * FROM info WHERE id_info='$id_info'", $db);
+$info_result=mysql_fetch_array ($info_query);
+if ($id_session[id_user] !=0) {$id_visitor=$id_session[id_user];} else $id_visitor=1;
+if ($task=="edit" && $current_user["level"] >= "50" || ($task=="edit" && ($id_visitor == $info_result[id_author])))
    {
-   if (isset($_GET['id_info'])) {$id_info=$_GET['id_info'];} else {$id_info="NULL";}
-   $info_query=mysql_query("SELECT * FROM info WHERE id_info='$id_info'", $db);
-   $info_result=mysql_fetch_array ($info_query);
+   if (isset($_GET['id_info'])) {$id_info=$_GET['id_info'];}
    $user_query=mysql_query("SELECT nick FROM users WHERE id_user='".$info_result["id_author"]."'", $db);
    $user_result=mysql_fetch_array ($user_query);
    $album_query=mysql_query("SELECT filename,id_photo FROM info_album WHERE id_info='$id_info'", $db);
@@ -329,15 +331,17 @@ if ($info_result["status"]==1 || $info_result["status"]==2)
 
    } else if ($task=="edit") echo "<tr><td colspan=4><span class=\"alert3b\"><center>$TEXT054</center></span></td></tr>";
 
-// If the user was loged and selects the edit option (task==edit), then he can modify the whole section.
+// task=editGUI
+
 $current_user_query=mysql_query("SELECT level FROM users WHERE id_user='".$id_session[id_user]."'", $db);
 $current_user=mysql_fetch_array ($current_user_query);
-
-if ($task=="editGUI" && $current_user["level"] >= "50")
+if (isset($_GET['id_info'])) {$id_info=$_GET['id_info'];} else if (isset($_POST['id_info'])) {$id_info=$_POST['id_info'];}
+$info_query=mysql_query("SELECT * FROM info WHERE id_info='$id_info'", $db);
+$info_result=mysql_fetch_array ($info_query);
+if ($id_session[id_user] !=0) {$id_visitor=$id_session[id_user];} else $id_visitor=1;
+if ($task=="editGUI" && $current_user["level"] >= "50" || ($task=="editGUI" && ($id_visitor == $info_result[id_author])))
    {
-   if (isset($_GET['id_info'])) {$id_info=$_GET['id_info'];} else {$id_info="NULL";}
-   $info_query=mysql_query("SELECT * FROM info WHERE id_info='$id_info'", $db);
-   $info_result=mysql_fetch_array ($info_query);
+   if (isset($_GET['id_info'])) {$id_info=$_GET['id_info'];}
    $user_query=mysql_query("SELECT nick FROM users WHERE id_user='".$info_result["id_author"]."'", $db);
    $user_result=mysql_fetch_array ($user_query);
    $album_query=mysql_query("SELECT filename,id_photo FROM info_album WHERE id_info='$id_info'", $db);
